Interface: TitleOptions | Chart.js
Description: Open source HTML5 Charts for your website

# # Interface: TitleOptions

## # Properties

### # align

• align: `Align`

Alignment of the title.

`default` 'center'

#### # Defined in

index.esm.d.ts:2410
(opens new window)

### # color

• color: `Color`

Color of text

`see` Defaults.color

#### # Defined in

index.esm.d.ts:2425
(opens new window)

### # display

• display: `boolean`

Is the title shown?

`default` false

#### # Defined in

index.esm.d.ts:2415
(opens new window)

### # font

• font: `ScriptableAndScriptableOptions`<`Partial`<`FontSpec`>, `ScriptableChartContext`>

#### # Defined in

index.esm.d.ts:2426
(opens new window)

### # fullSize

• fullSize: `boolean`

Marks that this box should take the full width/height of the canvas (moving other boxes). If set to `false`, places the box above/beside the chart area

`default` true

#### # Defined in

index.esm.d.ts:2433
(opens new window)

### # padding

• padding: `number` | { `bottom`: `number` ; `top`: `number` }

Adds padding above and below the title text if a single number is specified. It is also possible to change top and bottom padding separately.

#### # Defined in

index.esm.d.ts:2437
(opens new window)

### # position

• position: `"left"` | `"right"` | `"bottom"` | `"top"`

Position of title

`default` 'top'

#### # Defined in

index.esm.d.ts:2420
(opens new window)

### # text

• text: `string` | `string`[]

Title text to display. If specified as an array, text is rendered on multiple lines.

#### # Defined in

index.esm.d.ts:2441
(opens new window)